==> alluxio-underfs-wasb-2.4.1-2-sources.jar: alluxio/underfs/wasb/WasbUnderFileSystemFactory.java <==
/*
 * The Alluxio Open Foundation licenses this work under the Apache License, version 2.0
 * (the "License"). You may not use this work except in compliance with the License, which is
 * available at www.apache.org/licenses/LICENSE-2.0
 *
 * This software is distributed on an "AS IS" basis, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied, as more fully set forth in the License.
 *
 * See the NOTICE file distributed with this work for information regarding copyright ownership.
 */

package alluxio.underfs.wasb;

import alluxio.AlluxioURI;
import alluxio.underfs.UnderFileSystem;
import alluxio.underfs.UnderFileSystemConfiguration;
import alluxio.underfs.UnderFileSystemFactory;

import com.google.common.base.Preconditions;

import javax.annotation.concurrent.ThreadSafe;

/**
 * Factory for creating {@link WasbUnderFileSystem}.
 */
@ThreadSafe
public class WasbUnderFileSystemFactory implements UnderFileSystemFactory {

  /**
   * Constructs a new {@link WasbUnderFileSystemFactory}.
   */
  public WasbUnderFileSystemFactory() {}

  @Override
  public UnderFileSystem create(String path, UnderFileSystemConfiguration conf) {
    Preconditions.checkArgument(path != null, "path may not be null");
    return WasbUnderFileSystem.createInstance(new AlluxioURI(path), conf);
  }

  @Override
  public boolean supportsPath(String path) {
    return path != null
            && (path.startsWith(WasbUnderFileSystem.SCHEME_SECURE)
            || path.startsWith(WasbUnderFileSystem.SCHEME_INSECURE));
  }
}

==> alluxio-underfs-wasb-2.9.1-sources.jar: alluxio/underfs/wasb/WasbUnderFileSystemFactory.java <==
/*
 * The Alluxio Open Foundation licenses this work under the Apache License, version 2.0
 * (the "License"). You may not use this work except in compliance with the License, which is
 * available at www.apache.org/licenses/LICENSE-2.0
 *
 * This software is distributed on an "AS IS" basis, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied, as more fully set forth in the License.
 *
 * See the NOTICE file distributed with this work for information regarding copyright ownership.
 */

package alluxio.underfs.wasb;

import alluxio.AlluxioURI;
import alluxio.Constants;
import alluxio.underfs.UnderFileSystem;
import alluxio.underfs.UnderFileSystemConfiguration;
import alluxio.underfs.UnderFileSystemFactory;

import com.google.common.base.Preconditions;

import javax.annotation.concurrent.ThreadSafe;

/**
 * Factory for creating {@link WasbUnderFileSystem}.
 */
@ThreadSafe
public class WasbUnderFileSystemFactory implements UnderFileSystemFactory {

  /**
   * Constructs a new {@link WasbUnderFileSystemFactory}.
   */
  public WasbUnderFileSystemFactory() {}

  @Override
  public UnderFileSystem create(String path, UnderFileSystemConfiguration conf) {
    Preconditions.checkArgument(path != null, "path may not be null");
    return WasbUnderFileSystem.createInstance(new AlluxioURI(path), conf);
  }

  @Override
  public boolean supportsPath(String path) {
    return path != null
            && (path.startsWith(Constants.HEADER_WASB)
            || path.startsWith(Constants.HEADER_WASBS));
  }
}
